#!/usr/bin/env node
"use strict";

var _printInfo = _interopRequireDefault(require("./printInfo"));

var _getCurrentNames = _interopRequireDefault(require("./getCurrentNames"));

var _validateResponses = _interopRequireDefault(require("./validateResponses"));

var _moveAndroidJava = _interopRequireDefault(require("./tasks/moveAndroidJava"));

var _renamePackageManifest = _interopRequireDefault(require("./tasks/renamePackageManifest"));

var _renamePackageJavaFiles = _interopRequireDefault(require("./tasks/renamePackageJavaFiles"));

var _renamePackageBUCK = _interopRequireDefault(require("./tasks/renamePackageBUCK"));

var _renamePackageBuildGradle = _interopRequireDefault(require("./tasks/renamePackageBuildGradle"));

var _renameNameSettingsGradle = _interopRequireDefault(require("./tasks/renameNameSettingsGradle"));

var _renameNameMainJava = _interopRequireDefault(require("./tasks/renameNameMainJava"));

var _updateFullName = _interopRequireDefault(require("./tasks/updateFullName"));

var _updateAppJson = _interopRequireDefault(require("./tasks/updateAppJson"));

var _askQuestions = _interopRequireDefault(require("./askQuestions"));

var _verifyRN = _interopRequireDefault(require("./verifyRN"));

var _printStatus = _interopRequireDefault(require("./printStatus"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const tasks = [_moveAndroidJava.default, _renamePackageManifest.default, _renamePackageJavaFiles.default, _renamePackageBUCK.default, _renamePackageBuildGradle.default, _renameNameSettingsGradle.default, _renameNameMainJava.default, _updateFullName.default, _updateAppJson.default];

const rename = async data => {
  // eslint-disable-line max-statements
  let fails = 0,
      oks = 0;

  for (let i = 0; i < tasks.length; i++) {
    const item = tasks[i];
    console.info("- " + item.name);

    if (!item.if(data)) {
      console.info("✔ skipped, not needed");
      continue;
    }

    try {
      const stepResults = await item.fn(data);

      if (Array.isArray(stepResults)) {
        stepResults.forEach(({
          name,
          result
        }) => {
          // eslint-disable-line no-loop-func
          console.info("  - " + name);

          if (result instanceof Error) {
            console.info("    ✖ this step failed");
            fails++;
            return;
          }

          console.info("    ✔ ok");
          oks++;
        });
        continue;
      }

      console.info("  ✔ ok");
      oks++;
    } catch (e) {
      console.info("  ✖ this step failed");
      fails++;
      console.warn(e);
    }
  }

  return {
    fails,
    oks
  };
};

(async () => {
  try {
    await (0, _verifyRN.default)();
    (0, _printInfo.default)();
    const [fullName, name, packageName] = await (0, _getCurrentNames.default)();
    const namesData = await (0, _askQuestions.default)({
      fullName,
      name,
      packageName
    });
    console.info();
    (0, _validateResponses.default)(namesData);
    const results = await rename(namesData);
    (0, _printStatus.default)(results);
  } catch (e) {
    console.error(e.message);
  }
})();